@@ -2,24 +2,25 @@
  * @file libosso.h
  * This file is the public API for the Libosso library.
  *
- * Copyright (C) 2005-2006 Nokia Corporation.
+ * This file is part of libosso
+ *
+ * Copyright (C) 2005-2007 Nokia Corporation. All rights reserved.
  *
  * Contact: Kimmo Hmlinen <kimmo.hamalainen@nokia.com>
  *
  * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation;
- * version 2.1 of the License.
+ * modify it under the terms of the GNU Lesser General Public License
+ * version 2.1 as published by the Free Software Foundation.
  *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * This library is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
- *
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+ * 02110-1301 USA
  */
 
 #ifndef LIBOSSO_H_
@@ -72,7 +73,8 @@ typedef struct osso_af_context_t osso_context_t;
  * 'com.nokia.application', where 'application' is the value you gave as the
  * parameter. Note also that this argument must be identical to the
  * X-Osso-Service value in the desktop file, or the D-BUS daemon will kill
- * your application.
+ * your application. If you do not want to use the default 'com.nokia' prefix,
+ * you must pass the whole D-Bus service name, e.g. 'org.maemo.my_app'.
  * The only valid characters that the name may contain are letters a-z and
  * the underscore '_'.
  * @param version The version string of the application. It must be 
@@ -123,13 +125,13 @@ osso_rpc_t;
 
 /**
  * This function frees the contents of the #osso_rpc_t structure
- * pointed to be #rpc.  (It does not free the structure itself.)  You
+ * pointed to by rpc.  (It does not free the structure itself.)  You
  * need to call this for structures filled by #osso_rpc_run and
  * related functions.
  *
- * This function will call #g_free to free the memory pointed to by
- * #rpc->value.s when #rpc->type is #DBUS_TYPE_STRING.  This guarantee
- * allows you to use this function as the #retval_free parameter for
+ * This function will call g_free to free the memory pointed to by
+ * rpc->value.s when rpc->type is #DBUS_TYPE_STRING.  This guarantee
+ * allows you to use this function as the retval_free parameter for
  * #osso_rpc_set_cb_f, etc, when you get that string from #g_strdup,
  * #g_strdup_printf, etc.
  *
@@ -147,7 +149,7 @@ void osso_rpc_free_val (osso_rpc_t *rpc);
  * returns.
  * @param retval The return value of the method. This should be set to
  * DBUS_TYPE_INVALID for no reply.  See #osso_rpc_set_cb_f and
- * #osso_rpc_free_val for how the memory associated with #retval is
+ * #osso_rpc_free_val for how the memory associated with retval is
  * managed.
  * @param data An application specific pointer.
  * @return #OSSO_OK if the function executed successfully. retval is set to
@@ -166,7 +168,7 @@ typedef gint (osso_rpc_cb_f)(const gchar *interface, const gchar *method,
  * @param interface The interface of the remote object.
  * @param method The RPC function that was called.
  * @param retval The value that was returned.  The structure pointed
- * to by #retval and its contents are only valid until the callback
+ * to by retval and its contents are only valid until the callback
  * returns.
  * @param data An application specific pointer specified when the callback
  * was registered.
@@ -188,15 +190,12 @@ typedef void (osso_rpc_async_f)(const gchar *interface,
  * are:
  *  - DBUS_TYPE_BOOLEAN
  *    - The value is a gboolean.
- *  - DBUS_TYPE_INT, DBUS_TYPE_UINT
+ *  - DBUS_TYPE_INT32, DBUS_TYPE_UINT32
  *    - The value is an int or an unsigned int.
  *  - DBUS_TYPE_DOUBLE
  *    - The value is a float.
  *  - DBUS_TYPE_STRING
  *    - The value is a pointer to a string.
- *    - If the pointer is NULL it is translated to a DBUS_TYPE_NIL.
- *  - DBUS_TYPE_NIL
- *    - No value, this represents a NULL type.
  * @param osso The library context as returned by #osso_initialize.
  * @param service The service name of the remote service,
  * e.g. com.nokia.application.
@@ -233,20 +232,20 @@ osso_return_t osso_rpc_run (osso_context_t * osso, const gchar * service,
  * This is the type of the function used with
  * #osso_rpc_run_with_argfill, #osso_rpc_run_system_with_argfill, and
  * #osso_rpc_async_run_with_argfill to append the arguments to the
- * DBUS message #msg.
+ * D-Bus message msg.
  */
 typedef void osso_rpc_argfill (DBusMessage *msg, void *data);
 
 /**
  * This function is like #osso_rpc_run but instead of passing the
  * arguments for the DBUS message as a variable length argument list,
- * you provide a function in the #argfill parameter that will provide
- * the arguments.  The #argfill function is called with the
+ * you provide a function in the argfill parameter that will provide
+ * the arguments.  The argfill function is called with the
  * #DBusMessage object that is going to be sent and should append all
  * arguments to that object with #dbus_message_append_args, or
  * similar.
  *
- * The parameter #argfill_data will be passed to #argfill.
+ * The parameter argfill_data will be passed to argfill.
  *
  * WARNING: Using this function is not recommended, because it will
  * make your program more dependent on the DBus API due to the
@@ -362,13 +361,13 @@ osso_return_t osso_rpc_async_run (osso_context_t * osso,
 /**
  * This function is like #osso_rpc_async_run but instead of passing
  * the arguments for the DBUS message as a variable length argument
- * list, you provide a function in the #argfill parameter that will
- * provide the arguments.  The #argfill function is called with the
+ * list, you provide a function in the argfill parameter that will
+ * provide the arguments.  The argfill function is called with the
  * #DBusMessage object that is going to be sent and should append all
  * arguments to that object with #dbus_message_append_args, or
  * similar.
  *
- * The parameter #argfill_data will be passed to #argfill.
+ * The parameter argfill_data will be passed to argfill.
  *
  * WARNING: Using this function is not recommended, because it will
  * make your program more dependent on the DBus API due to the
@@ -422,7 +421,7 @@ osso_return_t osso_rpc_async_run_with_defaults (osso_context_t * osso,
 
 /**
  * The type for functions that free the contents of a #osso_rpc_t
- * structure that is used as a #retval with an RPC callback.  See
+ * structure that is used as a retval with an RPC callback.  See
  * #osso_rpc_set_cb_f_with_free.
  */
 typedef void osso_rpc_retval_free_f (osso_rpc_t *retval);
@@ -438,11 +437,11 @@ typedef void osso_rpc_retval_free_f (osso_rpc_t *retval);
  * @param data Arbitrary application specific pointer that will be passed
  * to the callback and ignored by Libosso.
  * @param retval_free A function that is called with the #osso_rpc_t
- * structure that has been filled by #cb when that structure is no
+ * structure that has been filled by cb when that structure is no
  * longer needed by libosso.  In particular, you should pass
- * #osso_rpc_free_val here when you set #retval->value.s to a string
- * that should be freed with #g_free.  Likewise, you should pass #NULL
- * here when you set #retval->value.s to a string that should not be
+ * #osso_rpc_free_val here when you set retval->value.s to a string
+ * that should be freed with g_free.  Likewise, you should pass NULL
+ * here when you set retval->value.s to a string that should not be
  * freed.
  * @return #OSSO_OK on success, #OSSO_INVALID if a parameter is
  * invalid, and #OSSO_ERROR if an error occurred.
@@ -453,8 +452,8 @@ osso_return_t osso_rpc_set_cb_f_with_free (osso_context_t * osso, const gchar *
 					   gpointer data,
 					   osso_rpc_retval_free_f *retval_free);
 
-/** Equivalent to #osso_rpc_set_cb_f_with_free when passing #NULL for
-    #retval_free.
+/** Equivalent to #osso_rpc_set_cb_f_with_free when passing NULL for
+    retval_free.
  */
 osso_return_t osso_rpc_set_cb_f (osso_context_t * osso, const gchar * service,
 				 const gchar * object_path,
@@ -478,7 +477,7 @@ osso_return_t osso_rpc_set_default_cb_f_with_free (osso_context_t * osso,
 						   osso_rpc_retval_free_f *retval_free);
 
 /** Equivalent to #osso_rpc_set_default_cb_f_with_free when passing
-    #NULL for #retval_free.
+    NULL for retval_free.
  */
 osso_return_t osso_rpc_set_default_cb_f (osso_context_t * osso,
 					 osso_rpc_cb_f * cb, gpointer data);
@@ -622,8 +621,8 @@ osso_return_t osso_application_top(osso_context_t *osso,
 
 /**
  * This is the type for the top callback function.
- * @deprecated {This feature will be removed from Libosso soon, use
- * osso_rpc functions instead}
+ * @deprecated This feature could be removed from Libosso soon, use
+ * osso_rpc functions instead.
  * 
  * @param arguments This string lists some extra parameters for the
  * application. It can be used to give the names of the files to open, etc.
@@ -636,8 +635,8 @@ typedef void(osso_application_top_cb_f)(const gchar *arguments,
 
 /**
  * This function registers a top event callback function.
- * @deprecated {This feature will be removed from Libosso soon, use
- * osso_rpc functions instead}
+ * @deprecated This feature could be removed from Libosso soon, use
+ * osso_rpc functions instead.
  * 
  * @param osso The library context as returned by #osso_initialize.
  * @param cb The callback function.
@@ -652,8 +651,8 @@ osso_return_t osso_application_set_top_cb(osso_context_t *osso,
 
 /**
  * This function unregisters a top event callback function.
- * @deprecated {This feature will be removed from Libosso soon, use
- * osso_rpc functions instead}
+ * @deprecated This feature could be removed from Libosso soon, use
+ * osso_rpc functions instead.
  * 
  * @param osso The library context as returned by #osso_initialize.
  * @param cb The callback function.
@@ -671,7 +670,7 @@ osso_return_t osso_application_unset_top_cb(osso_context_t *osso,
 /**
  * \defgroup Autosave Autosaving
  *
- * How to use autosave:<br />
+ * How to use autosave:<br>
  * The application registers callback function(s) that is/are called by
  * Libosso to save the user data (such as an unsaved document). Whenever
  * the user data changes, the
@@ -827,17 +826,81 @@ osso_return_t osso_time_set_notification_cb(osso_context_t *osso,
 					    osso_time_cb_f *cb,
 					    gpointer data);
 /**
- * This function sets the system and hardware time, and notifies about the
- * changing of time over the D-BUS system bus.
- * NOTICE: this function does not currently change the time or do anything
- * else useful.
+ * This function notifies about the changing of system time over the D-Bus
+ * system bus. The notification can be received by setting up a callback
+ * function with #osso_time_set_notification_cb. 
+ *
  * @param osso The library context as returned by #osso_initialize.
- * @param new_time The new time in epoch format.
+ * @param new_time The new time in epoch format. Must be greater than zero.
  * @return #OSSO_OK if all goes well, #OSSO_ERROR if an error occurred, or
  * #OSSO_INVALID if new_time or osso context is invalid.
  */
 osso_return_t osso_time_set(osso_context_t *osso, time_t new_time);
 
+/* @}*/
+/**
+ * \defgroup Locale Sending/receiving locale change notifications
+ */
+/* @{*/
+
+/**
+ * This is the type for the locale change notification callback function.
+ * @param new_locale The new locale (e.g. "en_GB")
+ * @param data An application specific data pointer.
+ *
+ * <h2>Example</h2>
+ * This is an example implementation of the locale change callback
+ * function. It correctly passes the received locale value to gettext
+ * and updates the labels for all the text widgets in the application.
+ * @code
+#include <libintl.h>
+#include <locale.h>
+#include <glib.h>
+
+static void locale_changed_cb (char *new_locale, gpointer user_data)
+{
+  GtkWidget *my_label = GTK_WIDGET (user_data);
+
+  g_setenv ("LANG", new_locale, TRUE);
+  setlocale (LC_MESSAGES, new_locale);
+
+  // Here you re-set the text labels for all your widgets. In this example
+  // only one widget is passed into the callback via user_data.
+
+  gtk_label_set_text (GTK_LABEL (my_label), _("Label Text"));
+
+  // The label's text will now be rendered in the new language
+}
+ * @endcode
+ */
+typedef void(osso_locale_change_cb_f)(const char *new_locale, gpointer data);
+
+/**
+ * This function registers a callback that is called whenever the locale is
+ * changed.
+ * @param osso The library context as returned by #osso_initialize.
+ * @param cb Function that is called when the system locale is changed.
+ * @param data Arbitrary application-specific pointer that will be passed
+ * to the callback and ignored by Libosso.
+ * @return #OSSO_OK if all goes well, #OSSO_ERROR if an error occurred, or
+ * #OSSO_INVALID if some parameter is invalid.
+ */
+osso_return_t osso_locale_change_set_notification_cb(osso_context_t *osso,
+					    osso_locale_change_cb_f *cb,
+					    gpointer data);
+
+/**
+ * This function issues a notification over the D-Bus system bus indicating
+ * a change of locale. To receive such a notification, install a callback
+ * function with #osso_locale_change_set_notification_cb. 
+ *
+ * @param osso The library context as returned by #osso_initialize.
+ * @param new_locale The new locale (e.g. "en_GB"). Must not be NULL.
+ * @return #OSSO_OK if all goes well, #OSSO_ERROR if an error occurred, or
+ * #OSSO_INVALID if new_locale is NULL or the osso context is invalid.
+ */
+osso_return_t osso_locale_set(osso_context_t *osso, char *new_locale);
+
 /* @}*/
 /**
  * \defgroup Sysnotes System notification
@@ -886,7 +949,7 @@ osso_return_t osso_system_note_dialog(osso_context_t *osso,
  * information banner).
  * This allows non-GUI applications to display some information to the user.
  * Applications that do have a GUI should not use this function, but the
- * gtk_infoprint widget directly.
+ * HildonBanner widget directly.
  * @param osso The library context as returned by #osso_initialize.
  * @param text The text to display on the infoprint.
  * @param retval This parameter will be used to store a possible return
@@ -931,9 +994,86 @@ struct state_data{
 };
  * @endcode
  * 
- * One particular version (the version is given to osso_initialize) of the
+ * One particular version (the version is given to osso_initialize()) of the
  * application can have only one state file.
  *
+ * Here are steps that an application could use to handle state saving
+ * (and auto-saving). The steps 1 and 2 (and possibly 10) should be done
+ * in startup of the application.
+ *
+ * 1) Register callback to execute when the application goes to background
+ *    and foreground:
+ * @code
+g_signal_connect(G_OBJECT(program), "notify::is-topmost",
+                 G_CALLBACK(topmost_status_change), data);
+ * @endcode
+ * Where program is the HildonProgram object, topmost_status_change is a
+ * function to execute when the application goes to background or
+ * foreground. The function could look like this:
+ * @code
+static void topmost_status_change(GObject *gobject,
+                                  GParamSpec *arg1,
+                                  gpointer data)
+{
+    HildonProgram *program = HILDON_PROGRAM(gobject);
+
+    if (hildon_program_get_is_topmost(program)) {
+        hildon_program_set_can_hibernate(program, FALSE);
+    } else {
+        save_state();
+        hildon_program_set_can_hibernate(program, TRUE);
+    }
+}
+ * @endcode
+ *
+ * 2) Read old UI state with osso_state_read(), if it exists. (Build the
+ *    UI according to the saved state, if it existed.)
+ *
+ * 3) Save the UI state with osso_state_write(), whenever the program
+ *    goes to background. If the UI was successfully saved, set the
+ *    'killable' flag with hildon_program_set_can_hibernate(). Note that
+ *    the killable flag should be set even if dialog contents could not be
+ *    completely saved, provided that the user does not lose data that
+ *    he/she input to the dialog.
+ *
+ * 4) Whenever the program goes to foreground, remove the killable
+ *    flag with hildon_program_set_can_hibernate().
+ *
+ * 5) Save the UI state before exiting when the user closes the
+ *    application.
+ *
+ * In addition to the above steps, follow these steps if the application
+ * handles 'user data' (e.g. unsaved draft document):
+ *
+ * 6) Register a callback function for saving the user data with
+ *    osso_application_set_autosave_cb().
+ *
+ * 7) When the application has unsaved user data, call
+ *    osso_application_userdata_changed(). This causes the autosave
+ *    callback to be called, after a timer has expired.
+ *
+ * 8) Whenever the application goes to background, call
+ *    osso_application_autosave_force() if the program has unsaved user
+ *    data.
+ *
+ * 9) When the application exits (for whatever reason), call
+ *    osso_application_autosave_force() if the program has unsaved user
+ *    data.
+ *
+ * 10) When the application is started the next time, check if there is
+ *     autosaved user data. If there is, the application should allow the
+ *     user to continue editing the data.
+ *
+ * Note that the state saving information is stored to volatile memory
+ * (RAM), but the autosaved information should be stored
+ * to non-volatile memory (e.g. the internal flash). This is partly because
+ * of reliability: this way the application cannot save a permanent,
+ * possibly corrupted, UI state that would crash or break the application
+ * whenever it is started (however, the autosaved user data could still
+ * do it).
+ *
+ * TODO: Libosso should provide more support for autosaving user data
+ *       (for saving, loading and removing it).
  */
 /* @{*/
 
@@ -1085,7 +1225,8 @@ typedef struct {
                                     user data (see Autosaving functions) */
   gboolean memory_low_ind; /**<The system is low on memory */
   gboolean system_inactivity_ind; /**<The application should reduce
-                                       its activity */
+                                      its activity. This also means that
+                                      the display went off/on. */
   osso_devmode_t sig_device_mode_ind; /**<The mode of the device */
 } osso_hw_state_t;
 
@@ -1095,7 +1236,9 @@ typedef struct {
  * or the touch screen. This can be used after completing a long operation
  * such as downloading a large file or after retrieving e-mails.
  * 
- * @return #OSSO_OK if all goes well, #OSSO_ERROR if an error occured.
+ * @param osso The library context as returned by #osso_initialize.
+ * @return #OSSO_OK if all goes well, #OSSO_ERROR if an error occured, and
+ * #OSSO_INVALID if the context is not valid.
  */ 
 
 osso_return_t osso_display_state_on(osso_context_t *osso);
@@ -1106,7 +1249,9 @@ osso_return_t osso_display_state_on(osso_context_t *osso);
  * by the video player during video playback. Also prevents suspending the
  * device.
  * 
- * @return #OSSO_OK if all goes well, #OSSO_ERROR if an error occured.
+ * @param osso The library context as returned by #osso_initialize.
+ * @return #OSSO_OK if all goes well, #OSSO_ERROR if an error occured, and
+ * #OSSO_INVALID if the context is not valid.
  */
 
 osso_return_t osso_display_blanking_pause(osso_context_t *osso);
@@ -1150,6 +1295,31 @@ osso_return_t osso_hw_set_event_cb(osso_context_t *osso,
 osso_return_t osso_hw_unset_event_cb(osso_context_t *osso,
 				     osso_hw_state_t *state);
 
+
+typedef enum {
+  OSSO_DISPLAY_ON,
+  OSSO_DISPLAY_OFF,
+  OSSO_DISPLAY_DIMMED
+} osso_display_state_t;
+
+typedef void(osso_display_event_cb_f)(osso_display_state_t state,
+                                      gpointer data);
+
+/**
+ * This function registers a callback that is called whenever the display
+ * state is changed. It is also called once directly after registering it,
+ * to tell about the current state.
+ * @param osso The library context as returned by #osso_initialize.
+ * @param cb Function that is called when the display state is changed.
+ * @param data Arbitrary application-specific pointer that will be passed
+ * to the callback and ignored by Libosso.
+ * @return #OSSO_OK if all goes well, #OSSO_ERROR if an error occurred, or
+ * #OSSO_INVALID if some parameter is invalid.
+ */
+osso_return_t osso_hw_set_display_event_cb(osso_context_t *osso,
+					   osso_display_event_cb_f *cb,
+					   gpointer data);
+
 /*@}*/
 /**********************************************************************/
 /**
@@ -1162,7 +1332,7 @@ osso_return_t osso_hw_unset_event_cb(osso_context_t *osso,
  * @param data The data pointer that was set with #osso_mime_set_cb.
  * @param argc The number of files to open.
  * @param argv An array of file URIs.  The strings
- * pointed to by the #argv array are only valid until the callback
+ * pointed to by the argv array are only valid until the callback
  * function returns.
  */
 typedef void (osso_mime_cb_f)(gpointer data, int argc, gchar **argv);
@@ -1191,6 +1361,9 @@ osso_return_t osso_mime_set_cb(osso_context_t *osso, osso_mime_cb_f *cb,
  * and OSSO_ERROR if there was an error.
  */
 osso_return_t osso_mime_unset_cb(osso_context_t *osso);
+
+osso_return_t osso_mime_unset_cb_full(osso_context_t *osso,
+                                      osso_mime_cb_f *cb, gpointer data);
 /*@}*/
 
 /**
@@ -1210,138 +1383,7 @@ gpointer osso_get_dbus_connection(osso_context_t *osso);
  */
 gpointer osso_get_sys_dbus_connection(osso_context_t *osso);
 
-
-
-/************************************************************************/
-/************************************************************************/
-/*******         OBSOLETE API BELOW -- DO NOT USE                     ***/
-/************************************************************************/
-/************************************************************************/
-
-/**
- * \defgroup outside Not included
- *
- * @note
- * This API is obsolete and should not be used by new code.
- *
- */
-/* @{*/
-
-/**
- * This is the type of the exit callback function.
- * @param die_now This parameter is obsolete and should be ignored.
- * @param data The data given to #osso_application_set_exit_cb.
- */
-typedef void (osso_application_exit_cb)(gboolean die_now, gpointer data);
-
-/**
- * This function registers the application's exit callback function.
- * When Libosso calls the application's exit callback function, the application
- * should save its GUI state and unsaved user data and exit as soon as possible.
- *
- * @param osso The library context as returned by #osso_initialize.
- * @param cb The exit callback function to register.
- * @param data Arbitrary application specific pointer that will be passed
- * to the callback and ignored by Libosso.
- * */
-osso_return_t osso_application_set_exit_cb(osso_context_t *osso,
-					   osso_application_exit_cb *cb,
-					   gpointer data);
-
-/**
- * This function opens a state file for writing. If the state file already
- * exists, it will be silently truncated.
- * @deprecated Use the more robust osso_state_write() function instead.
- * No new code should use this function.
- * @param osso The library context as returned by #osso_initialize.
- * @return the file descriptor of the opened file. On an error -1 is
- * returned.
- */
-int osso_state_open_write(osso_context_t *osso);
-
-/**
- * This function opens a state file for reading.
- * @deprecated Use the more robust osso_state_read() function instead.
- * No new code should use this function.
- * @param osso The library context as returned by #osso_initialize.
- * @return The file descriptor of the opened file. On an error -1 is
- * returned.
- */
-int osso_state_open_read(osso_context_t *osso);
-
-/**
- * This function closes the state file.
- * @deprecated Use the more robust osso_state_read() and 
- * osso_state_write() functions instead. No new code should use this
- * function.
- * @param osso The library context as returned by #osso_initialize.
- * @param fd The file descriptor to close.
- */
-void osso_state_close(osso_context_t *osso, gint fd);
-
-/** This function adds a mail to be displayed in the
- *      mail popup of the tasknavigator.
- *      @param osso The osso library context returned by #osso_initialize
- *      @param id unique identifier for the mail
- *      @param subject the subject string of the email
- *      @param sender the email address of the sender of the mail
- *      @param attachment true iff the mail has an attatchment
- *      @param date the date the mail was received.
- *
- *
- *      @return #OSSO_OK on success, #OSSO_ERROR in case of an error,
- *              #OSSO_INVALID if a parameter is invalid.
- */
-osso_return_t osso_tasknav_mail_add(osso_context_t *osso, guint id,
-				    const gchar *subject, const gchar *sender,
-				    gboolean attachment, const gchar *date);
-
-/** This function removes an email message from the navigator.
- *
- *      @param osso The osso library context returned by #osso_initialize
- *      @param id unique identifier of the mail to be destroyed
- *
- *      @return #OSSO_OK on success, #OSSO_ERROR in case of an error,
- *              #OSSO_INVALID if a paramter is invalid.
- *
- *
- */
-osso_return_t osso_tasknav_mail_del(osso_context_t *osso, guint id);
-
-/** This function updates the outbox message count in the task
- *      navigator mail window.
- *
- *      @param osso The osso library context returned by #osso_initialize
- *      @param count New number of messages in outbox
- *
- *      @return #OSSO_OK on success, #OSSO_ERROR in case of an error,
- *              #OSSO_INVALID if a paramter is invalid.
- *
- *
- */
-osso_return_t osso_tasknav_mail_set_outbox_count(osso_context_t *osso,
-						 guint count);
-
-/** Osso initialisation routine for applications to call.
- *  This ensures that the environment variables are transferred
- *  correctly before the gtk_init();
- *
- * 
- * @param application The name that this application is known as. This is  
- * not the name that a user sees, but rather the name that other
- * applications use as an address to communicate with this program.
- * @param version The version string of the application. It mus be simply
- * comparable with strcmp().
- * @param cb The callback function to used when application is topped.
- * @param callback_data An arbitrary pointer to some application specific data
- *              to pass to the top callback
-*/
-osso_context_t * osso_application_initialize(const gchar *application,
-					     const gchar *version,
-					     osso_application_top_cb_f *cb,
-					     gpointer callback_data);
-
-
+/*@}*/
 G_END_DECLS
 
 #endif /* LIBOSSO_H_*/
