@@ -1,20 +1,23 @@
 /**
- * Copyright (C) 2005  Nokia
+ * This file is part of libosso
+ *
+ * Copyright (C) 2005-2006 Nokia Corporation. All rights reserved.
  *
  * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
+ * modify it under the terms of the GNU Lesser General Public License
+ * version 2.1 as published by the Free Software Foundation.
  *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * This library is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+ * 02110-1301 USA
  */
+
 #include <assert.h>
 #include <stdio.h>
 #include <unistd.h>
@@ -50,10 +53,10 @@ int main(int nargs, char *argv[])
     if(osso == NULL)
 	return 1;
 
-    osso_rpc_set_default_cb_f(osso, cb, (gpointer)loop);
+    osso_rpc_set_default_cb_f(osso, (osso_rpc_cb_f*)cb, (gpointer)loop);
     dprint("cb = %p",cb);
     osso_rpc_set_cb_f(osso, TEST_SERVICE, TEST_OBJECT, TEST_IFACE,
-		      cb,(gpointer)loop);
+		      (osso_rpc_cb_f*)cb,(gpointer)loop);
     g_main_loop_run(loop);
     osso_deinitialize(osso);
 
